bloc_lint
library
Classes
AvoidBuildContextExtensions
The avoid_build_context_extensions lint rule.
AvoidFlutterImports
The avoid_flutter_imports lint rule.
AvoidPublicBlocMethods
The avoid_public_bloc_methods lint rule.
AvoidPublicFields
The avoid_public_fields lint rule.
BeginToken
The opening half of a grouping pair of tokens. This is used for curly
brackets ('{'), parentheses ('('), and square brackets ('[').
Diagnostic
A diagnostic which is reported by a lint rule.
IdentifierContext
Information about the parser state that is passed to the listener at the
time an identifier is encountered. It is also used by the parser for error
recovery when a recovery template is defined.
Keyword
The keywords in the Dart programming language.
LintContext
A context object that is provided to each LintRule and
provides APIs for reporting diagnostics and accessing the
current TextDocument .
Linter
A class that is able to analyze files and directories and
report diagnostics based on a registered set of lint rules.
LintRule
An individual lint rule.
Listener
A parser event listener that does nothing except throw exceptions
on parser errors.
Position
A specific position within a TextDocument .
PreferBloc
The prefer_bloc lint rule.
PreferBuildContextExtensions
The prefer_build_context_extensions lint rule.
PreferCubit
The prefer_cubit lint rule.
PreferFileNamingConventions
The prefer_file_naming_conventions lint rule.
PreferVoidPublicCubitMethods
The prefer_void_public_cubit_methods lint rule.
Range
A range of content within a TextDocument .
TextDocument
A simplified, Dart representation of VSCode's Language Server
TextDocument .
Token
A token that was scanned from the input. Each token knows which tokens
precede and follow it, acting as a link in a doubly linked list of tokens.
TokenType
The types of tokens that can be returned by the scanner.